#
# spec file for package python-pymod2pkg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sname pymod2pkg
Name:           python-pymod2pkg
Version:        0.28.0
Release:        1.4
Summary:        OpenStack Packaging - python module name to package name map
License:        Apache-2.0
Group:          Development/Libraries/Python
URL:            https://wiki.openstack.org/wiki/Rpm-packaging
Source0:        https://files.pythonhosted.org/packages/source/p/pymod2pkg/pymod2pkg-0.28.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-distro
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testresources
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
pymod2pkg is a simple python module for translating python module names to
corresponding package names which is a common problem in the packaging world.

%package -n python3-pymod2pkg
Summary:        OpenStack Packaging - python module name to package name map
Requires:       python3-distro
Requires:       python3-pbr >= 2.0.0
%if 0%{?suse_version}
Obsoletes:      python2-pymod2pkg < 0.23.0
%endif

%description -n python3-pymod2pkg
pymod2pkg is a simple python module for translating python module names to
corresponding package names which is a common problem in the packaging world.

This package contains the Python 3.x module.

%package -n python-pymod2pkg-doc
Summary:        Documentation for python module name to package name map library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-pymod2pkg-doc
Documentation for python module name to package name map library.

%prep
%autosetup -p1 -n pymod2pkg-0.28.0
%py_req_cleanup

%build
%{py3_build}

# generate html docs
%sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-pymod2pkg
%license LICENSE
%doc README*
%{_bindir}/pymod2pkg
%{_bindir}/reqs2pkg
%{python3_sitelib}/pymod2pkg
%{python3_sitelib}/pymod2pkg-%{version}*-info

%files -n python-pymod2pkg-doc
%doc doc/build/html
%license LICENSE

%changelog
* Sun Jan  7 2024 cloud-devel@suse.de
- removed 0001-add-suse_py39-flavor-to-explicitly-render-templates-.patch
- update to version 0.28.0
  - Moving IRC network reference to OFTC
  - Remove retired Qinling support
  - Remove retired Searchlight usage
  - add suse_py39 flavor to explicitly render templates for py39
  - Remove retired karbor usage
  - Add RDO mapping for psycopg2-binary
  - Remove retired Karbor support
  - Update package rules for some packages in the Redhat ecosystems
  - update to zed level jobs
  - Add python2 and python3 return values
  - Bump some requirements in lower-constraints.txt
  - Convert from "-" to "_" in setup.cfg
  - Add RDO mapping for semantic-version
  - Revert "Fix PyYAML mapping for RDO"
  - bump py37 to py38 in tox.ini
  - Move CLI code into it's own module
  - [tox] Update constraints, flake8 settings and default envlist
  - Add reqs2pkg
  - Use py3 as the default runtime for tox
  - remove unicode from code
  - [community goal] Update contributor documentation
  - Add doc/requirements
  - Retire django-openstack-auth
  - add suse_py311 flavor to explicitly render templates for py311
  - Add RDO mapping for suds-community
  - Add RDO mapping for prometheus-client
  - Change RDO mapping for sympy and protobuf
* Fri Mar  3 2023 cloud-devel@suse.de
- added 0001-add-suse_py39-flavor-to-explicitly-render-templates-.patch
* Tue Nov 17 2020 John Vandenberg <jayvdb@gmail.com>
- update to version 0.26.0
  * Fix PyYAML mapping for RDO
  * Stop to use the __future__ module
* Fri Jun  5 2020 cloud-devel@suse.de
- update to version 0.25.0
  - doc: update git clone url to opendev.org
  - Add ansible-runner
  - Switch to newer openstackdocstheme version
  - Cleanup py27 support
* Mon Apr 20 2020 Thomas Bechtold <tbechtold@suse.com>
- Add missing Obsoletes
* Wed Apr  1 2020 cloud-devel@suse.de
- update to version 0.23.0
  - Drop use of unittest2
  - [ussuri][goal] Drop python 2.7 support and testing
  - Switch away from deprecated distribution lookup
  - Fix some upstream mappings
* Mon Oct  7 2019 cloud-devel@suse.de
- update to version 0.22.1
  - Add neutron-dynamic-routing translation for RDO and SUSE
  - Fix pyOpenSSL mapping for RDO
  - Remove pyOpenSSL mapping for RDO
  - Add sphinxcontrib-svg2pdfconverter mapping for RDO
* Wed Sep  4 2019 cloud-devel@suse.de
- update to version 0.21.0
  - Translate tempest to openstack-tempest
* Wed Aug 28 2019 cloud-devel@suse.de
- update to version 0.20.1
  - Add openstack-placement rule for SUSE and RDO
* Fri Aug 23 2019 cloud-devel@suse.de
- update to version 0.20.0
  - Unify services list between rdo and suse
  - Add openstack-placement mapping
  - update git.openstack.org to opendev
  - Use sphinx-build for building the documentation
  - Add RDO mapping for semantic_version
* Tue Aug 20 2019 Thomas Bechtold <tbechtold@suse.com>
- update to version 0.19.0:
  * Add aodh and barbican rule for SUSE
  * Add networking-l2gw translation for RDO & SUSE
  * Add Python 3 Train unit tests
  * Switch to openstackdocstheme
  * OpenDev Migration Patch
* Tue Mar  5 2019 cloud-devel@suse.de
- update to version 0.18.0
  - flake8: update to 3.6.x
  - Fix zunclient mapping for SUSE
  - Add heat-cfntools translation for RDO
  - Add RDO/SUSE rule for heat-agents
  - Tighten the horizon plugin rule a bit more
  - Change openstack-dev to openstack-discuss
  - Use template for lower-constraints
  - Fix regression in neutron-fwaas-dashboard mapping
* Fri Dec 14 2018 cloud-devel@suse.de
- update to version 0.17.0
  - Add entry for python-octaviaclient
  - Add zun to the client/services list
  - fix tox python3 overrides
  - Change openstack-dev to openstack-discuss
  - added regex rule for horizon dashboard packages for suse
* Fri Dec 14 2018 cloud-devel@suse.de
- update to version 0.16.0
  - Add qinling client
  - Switch to stestr and remove flake8 from the list of dependencies
  - switch documentation job to new PTI
  - add python 3.6 unit test job
  - Add watcher service
  - import zuul job settings from project-config
* Tue Sep 11 2018 cloud-devel@suse.de
- update to version 0.14.0
  - Add RDO mapping for rtslib-fb
  - Add RDO mapping for sphinx_rtd_theme, remove unneeded dot
  - Update links in README
  - Translate ironic-python-agent for SUSE correctly
  - Add RDO mapping for ansible
  - Change RDO mapping for PyYAML, pyparsing and pytz
  - Updated from global requirements
  - add lower-constraints job
  - Added cyborg for SUSE and RDO mappings
* Fri Feb  9 2018 cloud-devel@suse.de
- update to version 0.13.1
  - Fix the name for freezer-web-ui
  - Add RDO mapping for APScheduler
* Wed Feb  7 2018 cloud-devel@suse.de
- update to version 0.13.0
  - Add packages needed for freezer
  - Add freezer-api and freezer-dr services
  - Updated from global requirements
* Tue Jan  2 2018 cloud-devel@suse.de
- update to version 0.11.0
  - Change default translation for py2 in RDO
  - Add RDO mapping for sysv_ipc
  - Switch to newer flake8 / python 3.x version
  - Avoid tox_install.sh for constraints support
  - Add freezer for SUSE and RDO
  - Updated from global requirements
* Wed Oct 11 2017 cloud-devel@suse.de
- update to version 0.10.1
  - Fix mappings for os-brick and mock
  - Add tripleo-common for RDO openstack- packages
  - add a number of simple mappings for RDO
* Wed Sep 13 2017 cloud-devel@suse.de
- update to version 0.10.0
  - Add SUSE exception for python-devel
  - Add mapping for unversioned names
* Tue Sep 12 2017 cloud-devel@suse.de
- update to version 0.9.0
  - Added name conversion support for tempest-plugin
  - Support FWaaS/VPNaaS horizon ui/dashboard plugins on SUSE
  - Add mapping of PyJWT for RDO
  - Add mapping of tempest-horizon for RDO
  - Add support for python3 packages
  - Updated from global requirements
* Tue Aug  1 2017 cloud-devel@suse.de
- update to version 0.8.3
  - Add mappings for monasca-transform and monasca-ceilometer
* Thu Jul 27 2017 cloud-devel@suse.de
- update to version 0.8.2
  - Add RDO and SUSE mappings for karbor
  - Update home-page according to doc migration
* Wed Jul 26 2017 cloud-devel@suse.de
- update to version 0.8.1
  - Fix SUSE mapping for libvirt-python
  - Add SUSE naming exception for ansible
  - Updated from global requirements
* Fri Jun  2 2017 cloud-devel@suse.de
- update to version 0.7.8
  - Drop py34 and add py35 in setup.cfg tox.ini
  - Add murano-dashboard rule
  - Updated from global requirements
  - Add mappings for networking-vsphere
  - Add rule for GitPython in RDO
* Thu May 18 2017 cloud-devel@suse.de
- update to version 0.7.7:
  - Add mappings for libvirt-python
* Wed Apr 26 2017 cloud-devel@suse.de
- update to version 0.7.6
  - Add mappings for masakari
  - Updated from global requirements
* Thu Apr 13 2017 cloud-devel@suse.de
- update to version 0.7.5
  - Change horizon mapping for RDO
* Thu Apr  6 2017 cloud-devel@suse.de
- update to version 0.7.4:
  - Correctly translate horizon for SUSE
  - Add RDO mapping rules for dnspython and xattr
  - Support horizon ui/dashboard plugins on SUSE
  - Translate python-glareclient for SUSE correctly
  - Add monasca projects as OpenStack projects
  - Updated from global requirements
  - Fix RDO mapping for pyScss
  - Add RDO mappings for pyscss, XStatic-term.js and nosexcover
* Mon Feb 20 2017 cloud-devel@suse.de
- update to version 0.7.2:
  - Fix mapping of pystache for RDO
  - Add RDO mapping for bandit
  - Add RDO rule for PyPi package ovs
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 0.7.1:
  - Add RDO mapping for supervisor
  - Add upstream rule for XStatic-smart-table
  - Add support for Ubuntu
  - Fix RDO mistral mapping
  - Add Constraints support
* Fri Dec 23 2016 cloud-devel@suse.de
- update to version 0.7.0:
  - Set proper XStatic mapping for RDO
  - [SUSE] Avoid double adding of "python" for python-ldap
  - Add SUSE mapping for mistral
  - Add upstream mapping rule for microversion_parse
  - Delete duplicate k8s mapping
  - Show team and repo badges on README
  - Changed the home-page link
  - Add mapping for Sphinx in RDO
  - Updated from global requirements
* Sun Oct  9 2016 dmueller@suse.com
- update to 0.6.0:
  * Fix cloudkittyclient to cloudkitty
  * Updated from global requirements
  * More exceptions for python-*client naming on SUSE
  * Updated from global requirements
  * Add additional mappings for new clients
  * Add mapping for OpenStack project names
* Tue Sep 27 2016 dmueller@suse.com
- add  0001-More-exceptions-for-python-client-naming-on-SUSE.patch
* Thu Sep 22 2016 dmueller@suse.com
- Add 0001-Add-additional-mappings-for-new-clients.patch
* Thu Sep  8 2016 tbechtold@suse.com
- update to 0.5.4:
  * Set proper package name for mistral in RDO
  * Remove aodh/gnocchiclient remapping
  * pypi name is Tempest, not tempest
* Tue Aug 30 2016 tbechtold@suse.com
- update to 0.5.3:
  * Use the proper name for pyOpenSSL in RDO
  * Add python-ironic-inspector-client exception for SUSE
  * Add python-cinderclient exceptions for SUSE case
  * Fix pika-pool translation for RDO
* Tue Aug  9 2016 tbechtold@suse.com
- update to 0.5.2:
  * RDO: add missing wsgi_intercept translation
  * Add more python-*client exceptions for SUSE case
* Mon Jul 25 2016 tbechtold@suse.com
- update to 0.5.1:
  * Add more exceptions for SUSE case
  * RDO: add mapping for suds-jurko
  * Add RDO horizon plugins mapping
  * Add a RegexRule TranslationRule class
  * Add missing RDO mapping
  * Update RDO services mapping
  * Updated from global requirements
* Thu Jun  9 2016 tbechtold@suse.com
- update to 0.4.0:
  * Move main class to own folder
  * Switch to pbr for building pymod2pkg
  * Updated from global requirements
  * Add pymod2pkg executable
  * Update from global requirements
  * Add Fedora/RDO rules for PyMySQL and MySQL-python
  * Add RDO rule for pyinotify
  * Deprecated tox -downloadcache option removed
  * Add licensing header
  * Restructure documentation
  * Fix py34 DB issue
  * Add tox.ini to be able to run tests
* Mon Sep 14 2015 tbechtold@suse.com
- Initial packaging (version 0.3)
